# nntime (Experimental Project)

See `examples/basic.py` for usage.

## Installation

[![PyPI version](https://badge.fury.io/py/nntime.svg)](https://badge.fury.io/py/nntime)

Install [PyTorch](https://pytorch.org/) and run:
```
pip install nntime
```
